@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 import warnings
-from typing import Awaitable, Callable, Literal, Optional
+from collections.abc import Awaitable, Callable
+from typing import Literal
 
 from .run import worker_serve
 from ..config import Config
@@ -13,8 +14,8 @@ async def serve(
     app: Framework,
     config: Config,
     *,
-    shutdown_trigger: Optional[Callable[..., Awaitable[None]]] = None,
-    mode: Optional[Literal["asgi", "wsgi"]] = None,
+    shutdown_trigger: Callable[..., Awaitable] | None = None,
+    mode: Literal["asgi", "wsgi"] | None = None,
 ) -> None:
     """Serve an ASGI or WSGI framework app given the config.
 
